@@ -62,13 +62,19 @@ class TestFuzzy:
     @pytest.mark.ckan_config(plugin.CONFIG_FUZZY, "on")
     @pytest.mark.parametrize("distance", [1, 2])
     def test_fuzzy_enabled(self, search, distance, ckan_config, monkeypatch):
-        monkeypatch.setitem(ckan_config, plugin.CONFIG_FUZZY_DISTANCE, distance)
+        monkeypatch.setitem(
+            ckan_config, plugin.CONFIG_FUZZY_DISTANCE, distance
+        )
         assert search()["q"] == "*:*"
         assert search(q="hello")["q"] == f"hello~{distance}"
-        assert search(q="hello world")["q"] == f"hello~{distance} world~{distance}"
+        assert (
+            search(q="hello world")["q"]
+            == f"hello~{distance} world~{distance}"
+        )
         assert search(q="hello:world")["q"] == f"hello:world"
         assert (
-            search(q="hello AND world")["q"] == f"hello~{distance} AND world~{distance}"
+            search(q="hello AND world")["q"]
+            == f"hello~{distance} AND world~{distance}"
         )
 
     @pytest.mark.ckan_config(plugin.CONFIG_FUZZY, "on")
@@ -76,7 +82,9 @@ class TestFuzzy:
     def test_fuzzy_enabled_with_too_low_distance(
         self, search, distance, ckan_config, monkeypatch
     ):
-        monkeypatch.setitem(ckan_config, plugin.CONFIG_FUZZY_DISTANCE, distance)
+        monkeypatch.setitem(
+            ckan_config, plugin.CONFIG_FUZZY_DISTANCE, distance
+        )
         assert search(q="")["q"] == "*:*"
         assert search(q="hello")["q"] == "hello"
         assert search(q="hello world")["q"] == "hello world"
@@ -88,7 +96,9 @@ class TestFuzzy:
     def test_fuzzy_enabled_with_too_high_distance(
         self, search, distance, ckan_config, monkeypatch
     ):
-        monkeypatch.setitem(ckan_config, plugin.CONFIG_FUZZY_DISTANCE, distance)
+        monkeypatch.setitem(
+            ckan_config, plugin.CONFIG_FUZZY_DISTANCE, distance
+        )
         assert search()["q"] == "*:*"
         assert search(q="hello")["q"] == "hello~2"
         assert search(q="hello world")["q"] == "hello~2 world~2"
